@@ -1,10 +1,7 @@
 import logging
 import json
 import os
-from .world.obstacle import Obstacle
-from .world.path_segment import PathSegment
-from .world.robot import RobotParameters
-from .world.world import World
+from .world import World
 
 
 class Persistence:
@@ -15,27 +12,30 @@ class Persistence:
 
     def dump(self) -> dict:
         return {
-            'path': [path_segment.dict() for path_segment in self.world.path],
             'robot': {'parameters': self.world.robot.parameters.dict()},
+            'usb_cameras': {id: camera.dict() for id, camera in self.world.usb_cameras.items()},
             'obstacles': {id: obstacle.dict() for id, obstacle in self.world.obstacles.items()},
         }
 
-    def load(self, dict: dict):
-        self.world.path = [PathSegment.parse_obj(path_segment) for path_segment in dict['path']]
-        self.world.robot.parameters = RobotParameters.parse_obj(dict['robot']['parameters'])
-        self.world.obstacles = {id: Obstacle.parse_obj(obstacle) for id, obstacle in dict['obstacles'].items()}
+    def load(self, world: World):
+        self.world.robot.parameters = world.robot.parameters
+        self.world.usb_cameras = world.usb_cameras
+        self.world.obstacles = world.obstacles
 
     def backup(self):
         os.makedirs(os.path.dirname(self.filepath), exist_ok=True)
         with open(self.filepath, 'w') as f:
             json.dump(self.dump(), f)
 
+    def parse_world(self, obj: dict):
+        return World.parse_obj(obj)
+
     def restore(self):
         if not os.path.exists(self.filepath):
             logging.warning('No backup file found.')
             return
         try:
             with open(self.filepath, 'r') as f:
-                self.load(json.load(f))
+                self.load(self.parse_world(json.load(f)))
         except:
-            logging.exception('Could not load from backup')
+            logging.exception(f'Could not load from backup at {self.filepath}')
