@@ -1,23 +1,22 @@
 import asyncio
-from typing import Callable
-from rosys.runtime import Runtime
-from rosys.world.mode import Mode
-from rosys.world.robot import Robot
-from rosys.world.world import World, WorldState
+from typing import Callable, Optional
+from .. import Runtime
+from ..world import AutomationState, Mode, Robot, World
 
 
 class TestRuntime(Runtime):
+    __test__ = False
     is_time_running: bool = True
 
-    def __init__(self, world: World = None):
+    def __init__(self, world: Optional[World] = None):
         if world is None:
-            world = World(mode=Mode.TEST, state=WorldState.RUNNING, robot=Robot())
+            world = World(mode=Mode.TEST, automation_state=AutomationState.RUNNING, robot=Robot())
         super().__init__(world)
         self.world.set_time(0)  # NOTE in tests we start at zero for better reading
 
         from .helper import set_global_runtime  # NOTE import here to avoid PytestAssertRewriteWarning
         set_global_runtime(self)
-        self.notifications = []
+        self.exception = None
 
     async def forward(self, seconds, dt=0.01):
         # NOTE we start runtime here because this makes it easy in the tests to prepare it beforehand
@@ -25,7 +24,7 @@ class TestRuntime(Runtime):
             for actor in self.actors:
                 actor.sleep = self.sleep
                 actor.run_cpu_bound = self.run_cpu_bound
-            await self.start()
+            await self.startup()
 
         end_time = self.world.time + seconds
         self.log.info(f'-------------------> forwarding to {round(end_time,2)}')
@@ -35,6 +34,9 @@ class TestRuntime(Runtime):
                 await asyncio.sleep(0)
             else:
                 await asyncio.sleep(0.01)
+            if self.exception is not None:
+                raise RuntimeError(f'error while forwarding time {dt} s') from self.exception
+
         self.log.info(f'-------------------> now it\'s {round(self.world.time,2)}')
 
     async def sleep(self, seconds: float):
@@ -42,18 +44,14 @@ class TestRuntime(Runtime):
         while self.world.time <= sleep_end_time:
             await asyncio.sleep(0)
 
-    async def run_cpu_bound(self, callback: Callable):
+    async def run_cpu_bound(self, callback: Callable, *args: any):
         try:
             self.is_time_running = False
             loop = asyncio.get_running_loop()
-            return await loop.run_in_executor(None, callback)
+            return await loop.run_in_executor(None, callback, *args)
         finally:
             self.is_time_running = True
 
-    def notify(self, message: str):
-        '''Notify the user.
-
-        Should be replaced and implemented by the user interface (as it's done in rosys.ui.configure).
-        '''
-        self.log.info(message)
-        self.notifications.append(message)
+    def handle_exception(self, ex: Exception):
+        super().handle_exception(ex)
+        self.exception = ex
