@@ -1,6 +1,6 @@
 from pydantic import BaseModel
 from typing import Optional
-from .hardware import HardwareGroup
+from ..helpers import ModificationContext
 from .pose import Pose
 from .velocity import Velocity
 
@@ -10,7 +10,7 @@ class RobotShape(BaseModel):
     height: float = 0.5
 
 
-class RobotParameters(BaseModel):
+class RobotParameters(BaseModel, ModificationContext):
     linear_speed_limit: float = 0.5
     angular_speed_limit: float = 0.5
     minimum_turning_radius: float = 0.0
@@ -23,7 +23,6 @@ class RobotParameters(BaseModel):
 class Robot(BaseModel):
     shape: RobotShape = RobotShape()
     parameters: RobotParameters = RobotParameters()
-    hardware: list[HardwareGroup] = []
     prediction: Pose = Pose()
     detection: Optional[Pose]
     simulation: Pose = Pose()
@@ -33,5 +32,6 @@ class Robot(BaseModel):
     hardware_time: Optional[float]
     battery: float = 0
     temperature: float = 0
+    emergency_stop: bool = False
     clock_offset: Optional[float]
     carrot: Optional[Pose]
